@@ -18,7 +18,7 @@ G_DEFINE_TYPE(JammoCollaborationPairComposition, jammo_collaboration_pair_compos
 
 #include "../../meam/jammo-sequencer.h"
 #include "../../meam/jammo-backing-track.h"
-#include "../jammo-track-view.h"
+#include "../jammo-editing-track-view.h"
 #include "../../meam/jammo-loop.h"
 #include "../../gems/gems_definitions.h"
 #include "../../gems/groupmanager.h"
@@ -28,15 +28,17 @@ G_DEFINE_TYPE(JammoCollaborationPairComposition, jammo_collaboration_pair_compos
 enum {
 	PROP_0,
 	PROP_OWN_TRACK_VIEW,
-	PROP_PEER_TRACK_VIEW
+	PROP_PEER_TRACK_VIEW,
+	PROP_JAMMO_THEME
 };
 
 struct _JammoCollaborationPairCompositionPrivate {
 
-	JammoTrackView * own_track_view;
-	JammoTrackView * peer_track_view;
+	JammoEditingTrackView * own_track_view;
+	JammoEditingTrackView * peer_track_view;
 	guint peer_user_id;
 	gboolean host;
+	jammo_theme * jammotheme;
 };
 
 // function prototypes
@@ -84,10 +86,11 @@ static void jammo_collaboration_pair_composition_add_jammo_sample_button_remote(
 	g_object_get(collaboration_pair_composition,"variation",&variation, NULL);
 
 	printf("got theme :'%s', variation: '%d'\n",theme,variation);
-	JammoSampleButton* sample_button = JAMMO_SAMPLE_BUTTON(theme_give_sample_button_for_this_theme_and_variation_for_this_id(theme,variation,loop_id));
+	//TODO:
+	JammoSampleButton* sample_button = NULL;// = JAMMO_SAMPLE_BUTTON(theme_give_sample_button_for_this_theme_and_variation_for_this_id(theme,variation,loop_id));
 
 	clutter_actor_meta_set_enabled(CLUTTER_ACTOR_META(tangle_actor_get_action_by_type(CLUTTER_ACTOR(sample_button), TANGLE_TYPE_DRAG_ACTION)), FALSE);
-	jammo_track_view_add_jammo_sample_button(collaboration_pair_composition->priv->peer_track_view, sample_button, slot);
+	jammo_editing_track_view_add_jammo_sample_button(collaboration_pair_composition->priv->peer_track_view, sample_button, slot);
 
 	printf("peer-track used (pointer:'%p')\n",collaboration_pair_composition->priv->peer_track_view);
 }
@@ -96,7 +99,7 @@ static void jammo_collaboration_pair_composition_remove_jammo_sample_button_remo
 	JammoCollaborationPairComposition * collaboration_pair_composition = JAMMO_COLLABORATION_PAIR_COMPOSITION(game);
 
 	printf("remote: remove_sample, uid %u, slot %u\n", user_id,  slot);
-	jammo_track_view_remove_jammo_sample_button_from_slot(collaboration_pair_composition->priv->peer_track_view, slot);
+	jammo_editing_track_view_remove_jammo_sample_button_from_slot(collaboration_pair_composition->priv->peer_track_view, slot);
 
 	printf("peer-track used (pointer:'%p')\n",collaboration_pair_composition->priv->peer_track_view);
 }
@@ -130,8 +133,8 @@ static void jammo_collaboration_pair_composition_set_property(GObject* object, g
 			if (collaboration_pair_composition->priv->own_track_view!=NULL) {
 				g_object_unref(collaboration_pair_composition->priv->own_track_view);
 			}
-			if (JAMMO_IS_TRACK_VIEW(g_value_get_object(value))) {
-				collaboration_pair_composition->priv->own_track_view = JAMMO_TRACK_VIEW(g_value_get_object(value));
+			if (JAMMO_IS_EDITING_TRACK_VIEW(g_value_get_object(value))) {
+				collaboration_pair_composition->priv->own_track_view = JAMMO_EDITING_TRACK_VIEW(g_value_get_object(value));
 			}
 			else {
 				collaboration_pair_composition->priv->own_track_view = NULL;
@@ -141,8 +144,8 @@ static void jammo_collaboration_pair_composition_set_property(GObject* object, g
 			if (collaboration_pair_composition->priv->peer_track_view!=NULL) {
 				g_object_unref(collaboration_pair_composition->priv->peer_track_view);
 			}
-			if (JAMMO_IS_TRACK_VIEW(g_value_get_object(value))) {
-				collaboration_pair_composition->priv->peer_track_view = JAMMO_TRACK_VIEW(g_value_get_object(value));
+			if (JAMMO_IS_EDITING_TRACK_VIEW(g_value_get_object(value))) {
+				collaboration_pair_composition->priv->peer_track_view = JAMMO_EDITING_TRACK_VIEW(g_value_get_object(value));
 				//Callback for multiplaying
 				printf("peer-track setted (pointer:'%p')\n",collaboration_pair_composition->priv->peer_track_view);
 				gems_set_callback_add_loop(jammo_collaboration_pair_composition_add_jammo_sample_button_remote);
@@ -153,6 +156,9 @@ static void jammo_collaboration_pair_composition_set_property(GObject* object, g
 				collaboration_pair_composition->priv->peer_track_view = NULL;
 			}
 			break;
+		case PROP_JAMMO_THEME:
+			collaboration_pair_composition->priv->jammotheme = g_value_get_pointer(value);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 			break;
@@ -171,6 +177,9 @@ static void jammo_collaboration_pair_composition_get_property(GObject* object, g
 		case PROP_PEER_TRACK_VIEW:
 			g_value_set_object(value, collaboration_pair_composition->priv->peer_track_view);
 			break;
+		case PROP_JAMMO_THEME:
+			g_value_set_pointer(value, collaboration_pair_composition->priv->jammotheme);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 			break;
@@ -237,7 +246,8 @@ void jammo_collaboration_pair_composition_game_callback(GObject * game, int type
 		g_object_set(collaboration_pair_composition,"theme",theme, NULL);
 		g_object_set(collaboration_pair_composition,"variation",variation, NULL);
 
-		composition_game_start_theme(theme,variation,jammo_get_actor_by_id("main-menu-view")); //Last parameter = where to go when game ends
+		jammo_theme* jammotheme = composition_game_start_theme(theme,variation,jammo_get_actor_by_id("main-menu-view")); //Last parameter = where to go when game ends
+		g_object_set(collaboration_pair_composition,"theme",jammotheme, NULL);
 	}
 }
 
@@ -290,13 +300,19 @@ static void jammo_collaboration_pair_composition_class_init(JammoCollaborationPa
 	                                g_param_spec_object("own-track-view",
 	                                "Own track view",
 	                                "Player's own track view",
-	                                JAMMO_TYPE_TRACK_VIEW, G_PARAM_READABLE | G_PARAM_WRITABLE));
+	                                JAMMO_TYPE_EDITING_TRACK_VIEW, G_PARAM_READABLE | G_PARAM_WRITABLE));
 
 	g_object_class_install_property(gobject_class, PROP_PEER_TRACK_VIEW,
 	                                g_param_spec_object("peer-track-view",
 	                                "Peer track view",
 	                                "Peer's track view",
-	                                JAMMO_TYPE_TRACK_VIEW, G_PARAM_READABLE | G_PARAM_WRITABLE));
+	                                JAMMO_TYPE_EDITING_TRACK_VIEW, G_PARAM_READABLE | G_PARAM_WRITABLE));
+
+	g_object_class_install_property(gobject_class, PROP_JAMMO_THEME,
+	                                g_param_spec_pointer("jammotheme",
+	                                "Theme",
+	                                "Theme",
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE));
 
 	g_type_class_add_private(gobject_class, sizeof(JammoCollaborationPairCompositionPrivate));
 }
