@@ -107,7 +107,8 @@ static int tempo_table[] = {0,140,110,90}; //variation1 is 140bpm, variation2 is
 
 //On advanced game, variation is not used, they are all using same set of sample_buttons
 ClutterActor* theme_give_sample_button_for_this_theme_and_variation_for_this_id(jammo_theme* theme, gchar* themename, guint variation, guint id){
-
+	if (theme->sample_button_array == NULL)
+		return NULL;
 	JammoSampleButton* sb = JAMMO_SAMPLE_BUTTON(g_ptr_array_index(theme->sample_button_array, id)); //clone this!
 	//It is unique, we can't return it.  We make clone of it.
 
@@ -123,21 +124,26 @@ static void pause_actors_animation(ClutterActor *actor, gpointer user_data) {
 	GList* children;
 	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(actor)); children; children = children->next) {
 		ClutterAnimation* animation = clutter_actor_get_animation (children->data);
-		ClutterTimeline* timeline = clutter_animation_get_timeline(animation);
-		clutter_timeline_pause(CLUTTER_TIMELINE(timeline));
+		if (animation) {
+			ClutterTimeline* timeline = clutter_animation_get_timeline(animation);
+			clutter_timeline_pause(CLUTTER_TIMELINE(timeline));
+		}
 	}
 }
 
 /* Actor for parameter is soundfamily-container.
-TODO: This can be called when sequencer is playing, and animations start.
 */
-static void unpause_actors_animation(ClutterActor *actor, gpointer user_data) {
+static void unpause_actors_animation(ClutterActor *actor, gpointer sequencer) {
 	//printf("unpause\n");
+	if (jammo_sequencer_get_position(JAMMO_SEQUENCER(sequencer))) //position==0 => 'not playing'-state
+		return; //If sequencer is playing, we do not want start any animation
 	GList* children;
 	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(actor)); children; children = children->next) {
 		ClutterAnimation* animation = clutter_actor_get_animation (children->data);
-		ClutterTimeline* timeline = clutter_animation_get_timeline(animation);
-		clutter_timeline_start(CLUTTER_TIMELINE(timeline));
+		if (animation) {
+			ClutterTimeline* timeline = clutter_animation_get_timeline(animation);
+			clutter_timeline_start(CLUTTER_TIMELINE(timeline));
+		}
 	}
 }
 
@@ -149,35 +155,6 @@ static void create_samplebutton(gchar* themename, gchar* variation, gchar* image
 	gchar *full_image = g_strdup_printf("%s/themes/%s/%s/%s",DATA_DIR,themename,variation,imagefile);
 	//printf("image file: '%s'\n",full_image);
 
-
-	/* If we are in listening mode, we do not need:
-	*pushable
-	*draggable
-	*animated
-	   sample_buttons
-	just make textures*/
-/*
-	if (theme->only_playing_mode) {
-		ClutterActor* icon = clutter_texture_new_from_file(full_image, NULL);
-		clutter_actor_set_position(icon, x, y);
-		tangle_widget_add(parent, icon, NULL);
-		return;
-		}
-*/
-
-	//This is good place to do menu for selecting icon for saved composition
-	if (x_place_for_icon<500) { //if 500px is used do not add anymore icons
-		ClutterActor* icon_button = tangle_button_new_with_background_actor(clutter_texture_new_from_file(full_image, NULL));
-		gchar* name_for_callback = g_strdup_printf("%s",full_image); //FIXME: this is not free'ed!
-		g_signal_connect (icon_button, "clicked", G_CALLBACK (save_image_pressed),theme);
-		clutter_actor_set_name(icon_button, name_for_callback);
-		clutter_actor_set_x(icon_button,x_place_for_icon);
-		clutter_actor_set_y(icon_button,200);
-		clutter_actor_set_width(icon_button,80); //This is the size/ratio when it is in cupboard
-		tangle_widget_add(TANGLE_WIDGET(container_for_buttons), icon_button, NULL);
-		x_place_for_icon+=clutter_actor_get_width(icon_button)+5;
-	}
-
 	gchar *full_sound = g_strdup_printf("%s/themes/%s/%s/%s",DATA_DIR,themename,variation,soundfile);
 	//printf("sound file: '%s'\n",full_sound);
 
@@ -191,6 +168,33 @@ static void create_samplebutton(gchar* themename, gchar* variation, gchar* image
 	g_ptr_array_add(theme->sample_button_array, sample_button);
 	static_counter_for_id++;
 
+	/* If we are in listening mode, we do not need:
+	*pushable
+	*draggable
+	*animated
+	   sample_buttons
+	*/
+
+	if (theme->only_playing_mode) {
+		clutter_actor_set_reactive(sample_button,FALSE);
+		}
+
+	else {
+	//This is good place to do menu for selecting icon for saved composition
+	if (x_place_for_icon<500) { //if 500px is used do not add anymore icons
+		ClutterActor* icon_button = tangle_button_new_with_background_actor(clutter_texture_new_from_file(full_image, NULL));
+		gchar* name_for_callback = g_strdup_printf("%s",full_image); //FIXME: this is not free'ed!
+		g_signal_connect (icon_button, "clicked", G_CALLBACK (save_image_pressed),theme);
+		clutter_actor_set_name(icon_button, name_for_callback);
+		clutter_actor_set_x(icon_button,x_place_for_icon);
+		clutter_actor_set_y(icon_button,200);
+		clutter_actor_set_width(icon_button,80); //This is the size/ratio when it is in cupboard
+		tangle_widget_add(TANGLE_WIDGET(container_for_buttons), icon_button, NULL);
+		x_place_for_icon+=clutter_actor_get_width(icon_button)+5;
+	}
+
+
+
 
 	//Each animation has own phase
 	int phase = (rand () % 100) + 1;
@@ -211,6 +215,7 @@ static void create_samplebutton(gchar* themename, gchar* variation, gchar* image
             NULL);
 	clutter_animation_set_loop (animation,TRUE);
 	g_object_unref(timeline1);
+	}
 
 	g_free(full_image);
 	g_free(full_sound);
@@ -247,7 +252,7 @@ static void menu_clicked (TangleButton *tanglebutton, gpointer user_data){
 	}
 }
 
-static ClutterActor* create_soundfamily_button(const gchar* theme_name, const gchar* button_name, gfloat x, gfloat y,TangleWidget* parent){
+static ClutterActor* create_soundfamily_button(jammo_theme* theme, const gchar* button_name, gfloat x, gfloat y,TangleWidget* parent){
 	ClutterActor* widget = tangle_widget_new();
 	tangle_widget_add(parent, widget,NULL);
 	clutter_actor_hide(widget);
@@ -257,10 +262,10 @@ static ClutterActor* create_soundfamily_button(const gchar* theme_name, const gc
 
 	//Do not ever start animations on pair-game:
 	if (!chum_get_pair_composition()) {
-		g_signal_connect(widget, "show", G_CALLBACK(unpause_actors_animation), NULL);
+		g_signal_connect(widget, "show", G_CALLBACK(unpause_actors_animation), theme->sequencer);
 	}
 
-	gchar* filename = g_strdup_printf("%s/%s/advanced/%s", THEMES_DIR, theme_name,button_name);
+	gchar* filename = g_strdup_printf("%s/%s/advanced/%s", THEMES_DIR, theme->name,button_name);
 	ClutterActor *menu_button =  tangle_button_new_with_background_actor(clutter_texture_new_from_file(filename, NULL));
 	g_free(filename);
 
@@ -569,10 +574,10 @@ jammo_theme* theme_create(const gchar* name,int variation, gboolean only_listeni
 
 else { //advanced
 	//Make buttons and containers for samplebuttons.
-	soundfamily[0] = create_soundfamily_button(name,"rhythmic_icon.png", 296.0, 103.0,TANGLE_WIDGET(view));
-	soundfamily[1] = create_soundfamily_button(name,"melodic_icon.png",  101.0, 164.0,TANGLE_WIDGET(view));
-	soundfamily[2] = create_soundfamily_button(name,"harmonic_icon.png", 631.0, 199.0,TANGLE_WIDGET(view));
-	soundfamily[3] = create_soundfamily_button(name,"effect_icon.png",   548.0,  26.0,TANGLE_WIDGET(view));
+	soundfamily[0] = create_soundfamily_button(theme,"rhythmic_icon.png", 296.0, 103.0,TANGLE_WIDGET(view));
+	soundfamily[1] = create_soundfamily_button(theme,"melodic_icon.png",  101.0, 164.0,TANGLE_WIDGET(view));
+	soundfamily[2] = create_soundfamily_button(theme,"harmonic_icon.png", 631.0, 199.0,TANGLE_WIDGET(view));
+	soundfamily[3] = create_soundfamily_button(theme,"effect_icon.png",   548.0,  26.0,TANGLE_WIDGET(view));
 
 	if (strncmp(name,"fantasy",7)==0){
 	//Rhythmic loops
