@@ -22,6 +22,14 @@ static gboolean goto_startmenu(ClutterActor *actor, ClutterEvent *event, gpointe
 
 gboolean start_gamesmenu()
 {
+	printf("\n For debugging purpose, start level2 instead of gamesmenu\n");
+	clutter_actor_show(jammo_get_actor_by_id("level2-view"));
+	clutter_actor_show(jammo_get_actor_by_id("fullsequencer-view"));
+	clutter_actor_hide(jammo_get_actor_by_id("startmenu-view"));
+	tangle_view_unload(TANGLE_VIEW(jammo_get_actor_by_id("startmenu-view")));
+	return FALSE;
+
+
 	//	tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
 	printf("Starting gamesmenu\n");
 
