@@ -403,6 +403,18 @@ static void on_duration_notify(GObject* object, GParamSpec* pspec, gpointer none
 //We want load saved composition only first time
 static gboolean first_time = TRUE;
 
+/*
+static void re_parent(ClutterActor* actor, gpointer data) {
+	ClutterContainer* container = CLUTTER_CONTAINER(data);
+*/
+static void re_parent(ClutterContainer* container,ClutterActor* actor) {
+	printf("re parenting\n");
+	g_object_ref(actor);
+	clutter_container_remove_actor(CLUTTER_CONTAINER(clutter_actor_get_parent(actor)), actor);
+	clutter_container_add(container,actor,NULL);   //add
+	g_object_unref(actor);
+	}
+
 /* JSON callback when sequencer-view is showed*/
 void start_sequencer_full_sequencer (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 	if (first_time){
@@ -411,6 +423,27 @@ void start_sequencer_full_sequencer (TangleAction *action, GObject *source, cons
 		g_free(filename);
 	}
 	first_time=FALSE;
+
+/*
+  track-views are defined in own json-file and they are always
+  in container called "starting-container-of-track-views"
+  We reparent them to "fullsequencer-container-for-tracks".
+*/
+	ClutterContainer* old_container = CLUTTER_CONTAINER(jammo_get_actor_by_id("starting-container-of-track-views"));
+	if (old_container ==NULL)
+		printf ("old_container ==NULL\n");
+
+	GList* children;
+	for (children=clutter_container_get_children(old_container); children; children=g_list_last(clutter_container_get_children(old_container)))
+	  re_parent(CLUTTER_CONTAINER(jammo_get_actor_by_id("fullsequencer-container-for-tracks")),children->data);
+
+
+	re_parent(CLUTTER_CONTAINER(jammo_get_actor_by_id("fullsequencer-track-control-panel")),jammo_get_actor_by_id("track-control-panel-of-this-level"));
+	clutter_actor_show(jammo_get_actor_by_id("track-control-panel-of-this-level"));
+
+	//Control-panel has correct height, but track area doesn't.
+	clutter_actor_set_height(jammo_get_actor_by_id("fullsequencer-container-for-tracks"),
+         clutter_actor_get_height(jammo_get_actor_by_id("fullsequencer-track-control-panel")));
 }
 
 /*
@@ -423,12 +456,7 @@ void start_sequencer(gpointer filename)
 	g_signal_connect_swapped(action, "clamp-offset-y", G_CALLBACK(tangle_widget_clamp_child_boundaries), jammo_get_actor_by_id("fullsequencer-view-container"));
 
 	static_sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
-	static_metronome_track = jammo_metronome_track_new();
-	jammo_sequencer_add_track(static_sequencer, JAMMO_TRACK(static_metronome_track));
-	jammo_metronome_track_set_time_signature_beats(static_metronome_track,4);
-	jammo_metronome_track_set_time_signature_note_value(static_metronome_track,4);
-	jammo_metronome_track_set_accent(static_metronome_track,FALSE);
-	jammo_playing_track_set_muted(JAMMO_PLAYING_TRACK(static_metronome_track), TRUE);
+	static_metronome_track = NULL;
 
 	//inputFilename is global! (from sequencer.h)
 	if (filename == NULL)
@@ -446,13 +474,15 @@ void start_sequencer(gpointer filename)
 	//Tune some things that can't be done with JSON only ("clamp-scrolling-offset-y")
 	sequencer_loop_tune_wheels();
 
+	sequencer_track_view_tune_width();
+
 	//Loading tracks from file:
 	if(inputFilename) {
 		FILE *ifp;
 		ifp = fopen(inputFilename, "r"); //currently open only for reading
 
 		if(ifp != NULL) {
-			load_state_from_file(inputFilename,TRUE);
+			load_state_from_file(inputFilename,FALSE);
 		}
 	} else {
 		printf("No file specified for sequencer.\n");
@@ -519,6 +549,14 @@ void sequencer_render_button_pressed (TangleButton* tanglebutton, gpointer none)
 
 void fullsequencer_metronome_clicked (TangleButton* tanglebutton, gpointer none){
 	printf("fullsequencer: Metronome pressed\n");
-
-	jammo_playing_track_set_muted(JAMMO_PLAYING_TRACK(static_metronome_track), !tangle_button_get_selected(tanglebutton));
+	if (static_metronome_track==NULL) {
+		static_metronome_track = jammo_metronome_track_new();
+		jammo_sequencer_add_track(static_sequencer, JAMMO_TRACK(static_metronome_track));
+		jammo_metronome_track_set_time_signature_beats(static_metronome_track,4);
+		jammo_metronome_track_set_time_signature_note_value(static_metronome_track,4);
+		jammo_metronome_track_set_accent(static_metronome_track,FALSE);
+		jammo_playing_track_set_muted(JAMMO_PLAYING_TRACK(static_metronome_track), FALSE);
+	}
+	else
+		jammo_playing_track_set_muted(JAMMO_PLAYING_TRACK(static_metronome_track), !tangle_button_get_selected(tanglebutton));
 }
