@@ -19,6 +19,7 @@ And then sequencer_track_view_add_with_type(sequencerTrackViewTYpe)
 #include "../../meam/jammo-midi.h"
 #include "../../meam/jammo-meam.h" //JAMMO_DURATION_INVALID
 
+#include "../jammo-track-view.h"
 #include "../jammo-editing-track-view.h"
 #include "../jammo-miditrack-view.h"
 #include "../jammo.h"
@@ -30,6 +31,7 @@ And then sequencer_track_view_add_with_type(sequencerTrackViewTYpe)
 #include "midi_editor.h"
 #include "instrument_gui.h"
 #include "jammer_view.h"
+#include "startmenu.h"
 
 #include "../../cem/cem.h"
 static int width_of_slot = 40;
@@ -40,9 +42,9 @@ static gfloat track_height = 50.0;
 //We get these as parameters
 static int number_of_slots = -1;
 
-static gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpointer user_data);
-static gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpointer user_data);
-static gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpointer data);
+gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpointer user_data);
+gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpointer user_data);
+gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpointer data);
 
 //We want toggle this up, when next is clicked
 TangleButton* last_pressed_volume_button = NULL;
@@ -280,12 +282,19 @@ ClutterActor* sequencer_track_view_add_with_type(gint track_view_type, gboolean
 /*
  * Event for pressing label on track, data points to track structure
  */
-static gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpointer data) {
+gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpointer data) {
+	ClutterActor* control_panel_for_this_track = clutter_actor_get_parent(CLUTTER_ACTOR(tanglebutton));
+	const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(control_panel_for_this_track));
+	TangleWidget* track_view;
 
-	SequencerTrackView* s_track_view = (SequencerTrackView*)data;
+	track_view = TANGLE_WIDGET(jammo_get_actor_by_id(name));
+	if (track_view==NULL) {
+		printf("Can't find what track is asked\n");
+		return FALSE;
+	}
 
 	printf("Pressed track label\n");
-	if (JAMMO_IS_MIDITRACK_VIEW(s_track_view->track_view))
+	if (JAMMO_IS_MIDITRACK_VIEW(track_view))
 	{
 		printf("It is instrument track\n");
 		//We can start realtime jamming or midi-editor.
@@ -294,32 +303,33 @@ static gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton
 		//TODO: some way to go straight to editor.
 
 		//jamming
-		instrument_gui_start(JAMMO_MIDITRACK_VIEW(s_track_view->track_view), NULL); //NULL means no slider
+		instrument_gui_start(JAMMO_MIDITRACK_VIEW(track_view), NULL); //NULL means no slider
 
 		//editor
 		//midi_editor_start_with_miditrack_view(JAMMO_MIDITRACK_VIEW(track->track_view));
 	}
-	else if (TANGLE_IS_WIDGET(s_track_view->track_view))
+	else if (JAMMO_IS_TRACK_VIEW(track_view))
 	{
 		printf("It is slider track or backing-track\n");
-		TangleWidget* container = TANGLE_WIDGET(s_track_view->track_view);
-		JammoTrack* track= JAMMO_TRACK(g_object_get_data(G_OBJECT(container),"track"));
+		TangleWidget* container2 = TANGLE_WIDGET(track_view);
+		JammoTrack* track;
+		g_object_get(track_view,"track",&track,NULL);
 		if (JAMMO_IS_SLIDER_TRACK(track)) {
 			printf(" it is slider_track\n");
-			instrument_gui_start(NULL, container); //NULL means no keyboard, but slider
+			instrument_gui_start(NULL, container2); //NULL means no keyboard, but slider
 		}
 		else if (JAMMO_IS_BACKING_TRACK(track)){
 			printf(" it is backing_track\n");
 			clutter_actor_show(jammo_get_actor_by_id("backingtrack-selection-view"));
 			clutter_actor_hide(jammo_get_actor_by_id("fullsequencer-view"));
 		}
-		else {
+	}
+	else if  (JAMMO_IS_EDITING_TRACK_VIEW(track_view)){
 			printf(" it is editing_track (start jammer)\n");
 			clutter_actor_show(jammo_get_actor_by_id("jammer-view"));
 			clutter_actor_hide(jammo_get_actor_by_id("fullsequencer-view"));
 			start_jammer();
 		}
-	}
 
 	return TRUE;
 }
@@ -332,22 +342,28 @@ gboolean fullsequencer_mentor_clicked (TangleButton *tanglebutton, gpointer data
 	return TRUE;
 }
 
-static gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpointer data)   {
-	printf("mute clicked\n");
-	SequencerTrackView *track_view = (SequencerTrackView*) data;
+gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpointer data)   {
+	ClutterActor* control_panel_for_this_track = clutter_actor_get_parent(CLUTTER_ACTOR(tanglebutton));
+	const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(control_panel_for_this_track));
+	printf("mute clicked: '%s'\n",name);
+	TangleWidget* track_view;
+
+	ClutterActor* container = jammo_get_actor_by_id("fullsequencer-container-for-tracks");
+	track_view = TANGLE_WIDGET(tangle_widget_get_nth_child(TANGLE_WIDGET(container),atoi(name)));
+
 	JammoPlayingTrack* jammotrack;
 
-	//slider and backingtrack is inside tangle_widget, midi- and loop-tracks are inside of jammo-*track-view
-	if (JAMMO_IS_EDITING_TRACK_VIEW(track_view->track_view) || JAMMO_IS_MIDITRACK_VIEW(track_view->track_view)) {
-		g_object_get(track_view->track_view, "track", &jammotrack, NULL);
-	} else if (TANGLE_IS_WIDGET(track_view->track_view)) {
-		jammotrack = JAMMO_PLAYING_TRACK(g_object_get_data(G_OBJECT(track_view->track_view),"track"));
+	//slider is inside tangle_widget, midi- and loop-tracks are inside of jammo-*track-view
+	if (JAMMO_IS_EDITING_TRACK_VIEW(track_view) || JAMMO_IS_MIDITRACK_VIEW(track_view)  || JAMMO_IS_TRACK_VIEW(track_view) ) {
+		g_object_get(track_view, "track", &jammotrack, NULL);
+	} else if (TANGLE_IS_WIDGET(track_view)) {
+		jammotrack = JAMMO_PLAYING_TRACK(g_object_get_data(G_OBJECT(track_view),"track"));
 	} else  {
 		return FALSE;
 	}
 
-
-	jammo_playing_track_set_muted(JAMMO_PLAYING_TRACK(jammotrack), tangle_button_get_selected(tanglebutton));
+	if (jammotrack)
+		jammo_playing_track_set_muted(JAMMO_PLAYING_TRACK(jammotrack), tangle_button_get_selected(tanglebutton));
 
 	return TRUE;
 }
@@ -371,12 +387,16 @@ gboolean sequencer_volumebar_used (ClutterActor *scroll_action, gpointer none){
 	JammoPlayingTrack* jammotrack = g_object_get_data(G_OBJECT(volume_scroller),"track");
 
 	gfloat new_volume = offset/height; //This is between [0...1]
+	if (jammo_playing_track_get_volume(jammotrack) == new_volume)
+		return FALSE;
+
 	jammo_playing_track_set_volume(jammotrack,new_volume);
 
 	gchar* message = g_strdup_printf("Volume changed to %f",new_volume);
 	cem_add_to_log(message,LOG_USER_ACTION);
 	g_free(message);
 
+	//These are for changing texture of volume-button
 	ClutterActor* container = tangle_button_get_normal_background_actor(last_pressed_volume_button);
 	ClutterActor* nub = tangle_widget_get_nth_child(TANGLE_WIDGET(container),0);
 
@@ -396,20 +416,28 @@ gboolean sequencer_volumebar_used (ClutterActor *scroll_action, gpointer none){
 /**
 Each tracks share one volumebar.
 */
-static gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpointer data) {
-	SequencerTrackView *track_view = (SequencerTrackView*) data;
+gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpointer data) {
+
+	ClutterActor* control_panel_for_this_track = clutter_actor_get_parent(CLUTTER_ACTOR(tanglebutton));
+	const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(control_panel_for_this_track));
+	printf("volume clicked: '%s'\n",name);
+	TangleWidget* track_view;
+
+	ClutterActor* container = jammo_get_actor_by_id("fullsequencer-container-for-tracks");
+	track_view = TANGLE_WIDGET(tangle_widget_get_nth_child(TANGLE_WIDGET(container),atoi(name)));
+
+	JammoPlayingTrack* jammotrack;
 
 	ClutterActor* volume_container = jammo_get_actor_by_id("fullsequencer-volumebar-container");
 	ClutterActor* volume_scroller = jammo_get_actor_by_id("fullsequencer-volumebar-scroller");
 	ClutterAction* scroll_action = tangle_actor_get_action_by_type(volume_scroller,TANGLE_TYPE_SCROLL_ACTION);
 
-	JammoPlayingTrack* jammotrack;
 
 	//slider and backingtrack is inside tangle_widget, midi- and loop-tracks are inside of jammo-*track-view
-	if (JAMMO_IS_EDITING_TRACK_VIEW(track_view->track_view) || JAMMO_IS_MIDITRACK_VIEW(track_view->track_view)) {
-		g_object_get(track_view->track_view, "track", &jammotrack, NULL);
-	} else if (TANGLE_IS_WIDGET(track_view->track_view)) {
-		jammotrack = JAMMO_PLAYING_TRACK(g_object_get_data(G_OBJECT(track_view->track_view),"track"));
+	if (JAMMO_IS_EDITING_TRACK_VIEW(track_view) || JAMMO_IS_MIDITRACK_VIEW(track_view)  || JAMMO_IS_TRACK_VIEW(track_view) ) {
+		g_object_get(track_view, "track", &jammotrack, NULL);
+	} else if (TANGLE_IS_WIDGET(track_view)) {
+		jammotrack = JAMMO_PLAYING_TRACK(g_object_get_data(G_OBJECT(track_view),"track"));
 	} else  {
 		return FALSE;
 	}
@@ -430,7 +458,7 @@ static gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpo
 		//-50 is height of the visible marker.
 		gfloat new_place = (clutter_actor_get_height(CLUTTER_ACTOR(volume_scroller))-50)*current_volume;
 		//printf("new place: %f\n",new_place);
-		tangle_object_animate(G_OBJECT(scroll_action),  CLUTTER_EASE_IN_OUT_QUAD, 250, "offset-y", new_place, NULL);
+		tangle_object_animate(G_OBJECT(scroll_action),  CLUTTER_EASE_IN_OUT_QUAD, 50, "offset-y", new_place, NULL);
 		g_object_set_data(G_OBJECT(volume_scroller),"track",jammotrack);
 		if (last_pressed_volume_button)
 			tangle_button_set_selected(last_pressed_volume_button,FALSE);
@@ -516,9 +544,9 @@ void fullsequencer_home_clicked (TangleButton* tanglebutton, gpointer none){
 	("\"pitch\" : \"%s\",\n\"tempo\" : %d,\n",jammo_sequencer_get_pitch(sequencer),jammo_sequencer_get_tempo(sequencer));
 
 	//save composition will return filename, but we are not interested in
-	g_free(save_composition("7-12/", jammo_get_actor_by_id("fullsequencer-container-for-tracks"),meta_data));
+//	g_free(save_composition("7-12/", jammo_get_actor_by_id("fullsequencer-container-for-tracks"),meta_data));
 	g_free(meta_data);
-	clutter_actor_show(jammo_get_actor_by_id("startmenu-view"));
+	startmenu_goto_startmenu(NULL,NULL);
 }
 
 
