@@ -13,14 +13,19 @@ This is the sequencer.
 #include "communitymenu.h"
 
 #include "../../cem/cem.h"
-ClutterActor* startmenu_group=NULL;
 
+//Used when coming back to startmenu (unload)
+static ClutterActor* last_used_level = NULL;
 
 void startmenu_goto_sequencer (TangleButton* tanglebutton, gpointer none){
 	printf("startmenu_goto_sequencer\n");
 
+	last_used_level = jammo_get_actor_by_id("level1-view");
+	clutter_actor_show(jammo_get_actor_by_id("level1-view")); //TODO: level1000-view (last-level)
 	clutter_actor_show(jammo_get_actor_by_id("fullsequencer-view"));
+
 	clutter_actor_hide(jammo_get_actor_by_id("startmenu-view"));
+	tangle_view_unload(TANGLE_VIEW(jammo_get_actor_by_id("startmenu-view")));
 }
 
 void startmenu_goto_gamesmenu (TangleButton* tanglebutton, gpointer none){
@@ -31,6 +36,7 @@ void startmenu_goto_gamesmenu (TangleButton* tanglebutton, gpointer none){
 void startmenu_goto_communitymenu(TangleButton* tanglebutton, gpointer none){
 	printf("startmenu_goto_communitymenu\n");
 	start_communitymenu();
+
 }
 
 void startmenu_mentor_clicked(TangleButton* tanglebutton, gpointer none){
@@ -56,7 +62,7 @@ void startmenu_right_arrow_clicked(TangleButton* tanglebutton, gpointer none){
 void startmenu_draw_version_information(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 	//Show version number: defined in configure.ac
 	gchar* version = g_strdup_printf("Version-%s",VERSION);
-	ClutterActor* version_label = clutter_text_new_with_text ("Luxi Mono 38",version);
+	ClutterActor* version_label = clutter_text_new_with_text ("Luxi Mono 36",version);
 	ClutterColor text_color = { 255, 255, 0, 255 };
 	clutter_actor_set_x(version_label,10.0);
 	clutter_text_set_color(CLUTTER_TEXT(version_label), &text_color);
@@ -72,12 +78,24 @@ void startmenu_draw_version_information(TangleAction *action, GObject *source, c
 	*/
 }
 
+void startmenu_quit (TangleButton* tanglebutton, gpointer none){
+	cem_add_to_log("startmenu_quit-called",LOG_USER_ACTION);
+	clutter_main_quit();
+}
 
 /*
 Whenever any view want return back to startmenu, this function can be used
 */
 void startmenu_goto_startmenu (TangleButton* tanglebutton, gpointer none){
 	cem_add_to_log("startmenu_goto_startmenu-called",LOG_USER_ACTION);
+	tangle_view_unload(TANGLE_VIEW(jammo_get_actor_by_id("fullsequencer-view")));
+
+	//TODO!
+	if (last_used_level)
+		tangle_view_unload(TANGLE_VIEW(jammo_get_actor_by_id("level1-view")));
+	else
+		tangle_view_unload(TANGLE_VIEW(jammo_get_actor_by_id("level2-view")));
+
 	ClutterActor* mainview;
 	mainview = jammo_get_actor_by_id("main-views-widget");
 	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
