@@ -288,6 +288,19 @@ static void jammo_editing_track_view_constructed(GObject* object) {
 	g_signal_connect(drop_action, "drag-end", G_CALLBACK(on_drag_end), track_view);
 	g_signal_connect(drop_action, "dropped", G_CALLBACK(on_dropped), track_view);
 	clutter_actor_add_action(CLUTTER_ACTOR(track_view), drop_action);
+
+	g_object_set(track_view,"slot-duration",2653512050,NULL); //Fixme!
+
+	/* //Track is not ready yet?
+	JammoEditingTrack* track=track_view->priv->track;
+	if (track) {
+		guint n_slots = track_view->priv->n_slots;
+		guint64 duration = jammo_editing_track_get_fixed_duration(track);
+		printf("n_slots %d, duration %llu\n",n_slots,duration);
+
+		g_object_set(track_view,"slot-duration",duration/n_slots);
+	}
+	*/
 }
 
 static void jammo_editing_track_view_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
@@ -447,7 +460,7 @@ static void jammo_editing_track_view_class_init(JammoEditingTrackViewClass* trac
 	                                "Slot duration",
 	                                "The duration of a slot in nanoseconds",
 	                                0, G_MAXUINT64, 0,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 	/**
 	 * JammoEditingTrackView:slot-height:
 	 *
