@@ -9,7 +9,7 @@
  */
 
 #include "jammo-sample-button.h"
-#include "jammo-track-view.h"
+#include "jammo-editing-track-view.h"
 #include "../meam/jammo-sequencer.h"
 #include <string.h>
 
@@ -482,7 +482,7 @@ static void on_drag_end(ClutterDragAction* action, ClutterActor* actor, gfloat e
 	ClutterActor* parent;
 	
 	parent = clutter_actor_get_parent(actor);
-	if (JAMMO_IS_TRACK_VIEW(parent)) {
+	if (JAMMO_IS_EDITING_TRACK_VIEW(parent)) {
 		clutter_container_remove_actor(CLUTTER_CONTAINER(parent), CLUTTER_ACTOR(actor));
 	}
 }
