@@ -12,6 +12,7 @@
 #include "../meam/jammo-meam.h"
 #include "jammo-mentor.h"
 #include "jammo-mentor-action.h"
+#include "jammo-track-view.h"
 #include <tangle.h>
 #include <clutter/clutter.h>
 #include <stdlib.h> 
@@ -271,7 +272,7 @@ int main(int argc, char** argv) {
 	create_directories();
 
 	/* TODO: Temporary: make sure Mentor classes exists. */
-	printf("%ld %ld\n", (long)JAMMO_TYPE_MENTOR, (long)JAMMO_TYPE_MENTOR_ACTION);
+	printf("%ld %ld %ld\n", (long)JAMMO_TYPE_MENTOR, (long)JAMMO_TYPE_MENTOR_ACTION, (long)JAMMO_TYPE_TRACK_VIEW);
 
 	if ((stylesheet = get_jammo_stylesheet())) {
 		tangle_stylesheet_set_default(stylesheet);
