@@ -356,7 +356,7 @@ static void jammo_editing_track_class_init(JammoEditingTrackClass* editing_track
 	                                "Fixed duration",
 	                                "The fixed duration of the track or JAMMO_DURATION_INVALID if the track duration is dynamic",
 	                                0, G_MAXUINT64, JAMMO_DURATION_INVALID,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 
 	/**
 	 * JammoEditingTrack:sample-added:
