@@ -17,7 +17,7 @@
 
 #define JAMMO_TYPE_EDITING_TRACK (jammo_editing_track_get_type ())
 #define JAMMO_EDITING_TRACK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), JAMMO_TYPE_EDITING_TRACK, JammoEditingTrack))
-#define JAMMO_IS_EDITING_TRACK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), JAMMO_TYPE_EDITING_GTRACK))
+#define JAMMO_IS_EDITING_TRACK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), JAMMO_TYPE_EDITING_TRACK))
 #define JAMMO_EDITING_TRACK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), JAMMO_TYPE_EDITING_TRACK, JammoEditingTrackClass))
 #define JAMMO_IS_EDITING_TRACK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), JAMMO_TYPE_EDITING_TRACK))
 #define JAMMO_EDITING_TRACK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), JAMMO_TYPE_EDITING_TRACK, JammoEditingTrackClass))
