@@ -13,6 +13,10 @@
 #include "jammo-meam-private.h"
 #include "jammo-pipeline.h"
 
+#include <clutter/clutter.h>
+
+#define BUFFER_TIME 10000
+
 /**
  * SECTION:jammo-sequencer
  * @Short_description: A multitrack sequencer
@@ -26,7 +30,10 @@
  * associated #JammoTrack objects.
  */
 
-G_DEFINE_TYPE(JammoSequencer, jammo_sequencer, G_TYPE_OBJECT);
+static void clutter_scriptable_iface_init(ClutterScriptableIface* iface);
+
+G_DEFINE_TYPE_WITH_CODE(JammoSequencer, jammo_sequencer, G_TYPE_OBJECT,
+                        G_IMPLEMENT_INTERFACE(CLUTTER_TYPE_SCRIPTABLE, clutter_scriptable_iface_init););
 
 enum {
 	PROP_0,
@@ -46,7 +53,6 @@ enum {
 struct _JammoSequencerPrivate {
 	guint tempo;
 	gchar* pitch;
-	gint64 latency;
 
 	GstElement* pipeline;
 	GstElement* bin;
@@ -72,14 +78,12 @@ static gboolean setup_audiosink(JammoSequencer* sequencer);
 static gboolean setup_filesink(JammoSequencer* sequencer, const gchar* filename);
 static void start_playing(JammoSequencer* sequencer);
 
+static ClutterScriptableIface* parent_scriptable_iface = NULL;
 static guint signals[LAST_SIGNAL] = { 0 };
 
 // quality for ogg file created in file mode
 #define OGGQUALITY 0.5
 
-// default latency, will be used if no track requests lower
-#define DEFAULT_LATENCY 80000
-
 /**
  * jammo_sequencer_new:
  *
@@ -269,7 +273,6 @@ JammoTrack* jammo_sequencer_get_track(JammoSequencer* sequencer, guint index) {
  */
 void jammo_sequencer_add_track(JammoSequencer* sequencer, JammoTrack* track) {
 	GstElement* element;
-	gint64 desired_latency;
 	
 	if (g_list_find(sequencer->priv->tracks, track)) {
 		g_warning("A track is already added into a sequencer.");
@@ -284,6 +287,12 @@ void jammo_sequencer_add_track(JammoSequencer* sequencer, JammoTrack* track) {
 			gst_element_link(element, sequencer->priv->adder);
 		} else {
 			gst_bin_remove(GST_BIN(sequencer->priv->bin), element);
+			
+			/* Dirty fix: We know that the track is JammoRecordingTrack. Singing game requires
+			 * addition buffers in order to work decently in Nokia N900, which has latency isses.
+			 */
+			g_print("Added some buffers into pulse sink to help recording.\n");
+			g_object_set(G_OBJECT(sequencer->priv->audiosink), "buffer-time", (gint64)80000, NULL);
 		}
 
 		sequencer->priv->duration = 0;
@@ -297,11 +306,6 @@ void jammo_sequencer_add_track(JammoSequencer* sequencer, JammoTrack* track) {
 			sequencer->priv->ready = FALSE;
 			g_object_notify(G_OBJECT(sequencer), "ready");
 		}
-		desired_latency=_jammo_track_latency_query(track);
-		if (desired_latency>0 && desired_latency<sequencer->priv->latency) {
-			sequencer->priv->latency=desired_latency;
-			jammo_sequencer_set_latency(sequencer, sequencer->priv->latency);
-		}
 	}
 }
 
@@ -433,36 +437,6 @@ gboolean jammo_sequencer_set_output_filename(JammoSequencer* sequencer, const gc
 	return retvalue;
 }
 
-/**
- * jammo_sequencer_get_latency:
- * @sequencer: a #JammoSequencer
- *
- * Returns the latency of audiosink.
- *
- * Return value: latency in us or -1 on error
- */
-gint64 jammo_sequencer_get_latency(JammoSequencer* sequencer) {
-	if (sequencer->priv->audiosink) {
-		gint64 latency;
-		g_object_get(G_OBJECT(sequencer->priv->audiosink), "buffer-time", &latency, NULL);
-		return latency;
-	}
-	return -1;
-}
-
-/**
- * jammo_sequencer_set_latency:
- * @sequencer: a #JammoSequencer
- * @latency: the requested latency
- *
- * Sets the latency of audiosink.
- */
-void jammo_sequencer_set_latency(JammoSequencer* sequencer, gint64 latency) {
-	if (sequencer->priv->audiosink) {
-		g_object_set(G_OBJECT(sequencer->priv->audiosink), "buffer-time", latency, NULL);
-	}
-}
-
 static void jammo_sequencer_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
 	JammoSequencer* sequencer;
 	
@@ -633,7 +607,6 @@ static void jammo_sequencer_init(JammoSequencer* sequencer) {
 
 	sequencer->priv->ready = TRUE;
 	sequencer->priv->tempo = 110;
-	sequencer->priv->latency = DEFAULT_LATENCY;
 
 	sequencer->priv->pipeline = jammo_pipeline_new(NULL);
 	bus = gst_pipeline_get_bus(GST_PIPELINE(sequencer->priv->pipeline));
@@ -650,6 +623,73 @@ static void jammo_sequencer_init(JammoSequencer* sequencer) {
 	}
 }
 
+static gboolean jammo_sequencer_parse_custom_node(ClutterScriptable* scriptable, ClutterScript* script, GValue* value, const gchar* name, JsonNode* node) {
+	gboolean retvalue = FALSE;
+	GSList* slist = NULL;
+	JsonArray* array;
+	gint i;
+	JsonNode* n;
+	GObject* object;
+	
+	if (!g_strcmp0(name, "tracks")) {
+		if (JSON_NODE_TYPE(node) != JSON_NODE_ARRAY) {
+			g_warning("Expected JSON array for '%s', skipped.", name);
+		} else {
+			array = json_node_get_array(node);
+			for (i = json_array_get_length(array) - 1; i >= 0; i--) {
+				n = json_array_get_element(array, i);
+				if (JSON_NODE_TYPE(n) != JSON_NODE_VALUE || json_node_get_value_type(n) != G_TYPE_STRING) {
+					g_warning("Expected a string value in '%s' array, skipped.", name);
+				} else if (!(object = clutter_script_get_object(script, json_node_get_string(n)))) {
+					g_warning("A reference to non-existing object '%s' in '%s' array, skipped.", json_node_get_string(n), name);
+				} else {
+					slist = g_slist_prepend(slist, object);
+				}
+			}
+					
+			g_value_init(value, G_TYPE_POINTER);
+			g_value_set_pointer(value, slist);
+
+			retvalue = TRUE;
+		}
+	} else if (parent_scriptable_iface->parse_custom_node) {
+		retvalue = parent_scriptable_iface->parse_custom_node(scriptable, script, value, name, node);
+	}
+	
+	return retvalue;
+}
+
+static void jammo_sequencer_set_custom_property(ClutterScriptable* scriptable, ClutterScript* script, const gchar* name, const GValue* value) {
+	JammoSequencer* sequencer;
+	GSList* slist;
+	GSList* slist_item;
+	
+	sequencer = JAMMO_SEQUENCER(scriptable);
+	
+	if (!g_strcmp0(name, "tracks")) {
+		g_return_if_fail(G_VALUE_HOLDS(value, G_TYPE_POINTER));
+
+		slist = (GSList*)g_value_get_pointer(value);
+		for (slist_item = slist; slist_item; slist_item = slist_item->next) {
+			jammo_sequencer_add_track(sequencer, JAMMO_TRACK(slist_item->data));
+		}
+		g_slist_free(slist);	
+	} else if (parent_scriptable_iface->set_custom_property) {
+		parent_scriptable_iface->set_custom_property(scriptable, script, name, value);
+	} else {
+		g_object_set_property(G_OBJECT(scriptable), name, value);
+	}
+}
+
+static void clutter_scriptable_iface_init(ClutterScriptableIface* iface) {
+	if (!(parent_scriptable_iface = g_type_interface_peek_parent (iface))) {
+		parent_scriptable_iface = g_type_default_interface_peek(CLUTTER_TYPE_SCRIPTABLE);
+	}
+	
+	iface->parse_custom_node = jammo_sequencer_parse_custom_node;
+	iface->set_custom_property = jammo_sequencer_set_custom_property;
+}
+
 static gboolean on_bus_message(GstBus* bus, GstMessage* message, gpointer data) {
 	JammoSequencer* sequencer;
 	GError* error;
@@ -741,7 +781,6 @@ static gboolean setup_audiosink(JammoSequencer* sequencer) {
 	
 	if ((sequencer->priv->queue = create_element("queue")) &&
 	    (sequencer->priv->audiosink = create_element("pulsesink"))) {
-	    	g_object_set(sequencer->priv->audiosink, "buffer-time", DEFAULT_LATENCY, NULL);
 		gst_bin_add_many(GST_BIN(sequencer->priv->bin), sequencer->priv->queue, sequencer->priv->audiosink, NULL);
 		if (!gst_element_link_many(sequencer->priv->adder, sequencer->priv->queue, sequencer->priv->audiosink, NULL)) {
 			g_critical("Failed to link pulsesink.");
